@@ -224,8 +224,14 @@ parse_args (int    argc,
 
         else if (match ("--list-all")) {
             guint   n_operations;
-            gchar **operations = gegl_list_operations (&n_operations);
             gint    i;
+            gchar **operations;
+
+            /* initializing opencl for no use in this meta-data only query */
+            g_object_set (gegl_config (), "use-opencl", FALSE, NULL);
+            gegl_init (NULL, NULL);
+
+            operations  = gegl_list_operations (&n_operations);
 
             for (i = 0; i < n_operations; i++)
               {
@@ -238,6 +244,9 @@ parse_args (int    argc,
 
         else if (match ("--exists")) {
             gchar   *op_name;
+            /* initializing opencl for no use in this meta-data only query */
+            g_object_set (gegl_config (), "use-opencl", FALSE, NULL);
+            gegl_init (NULL, NULL);
 
             /* The option requires at least one argument. */
             get_string (op_name);
@@ -255,6 +264,10 @@ parse_args (int    argc,
             gchar  *op_name;
             get_string (op_name);
 
+            /* initializing opencl for no use in this meta-data only query */
+            g_object_set (gegl_config (), "use-opencl", FALSE, NULL);
+            gegl_init (NULL, NULL);
+
             if (gegl_has_operation (op_name))
               {
                 gint         i;
