@@ -26,7 +26,6 @@
 #include <glib/gprintf.h>
 
 #include "gegl.h"
-#include "gegl-types-internal.h"
 #include "gegl-buffer-types.h"
 #include "gegl-buffer-iterator.h"
 #include "gegl-buffer-iterator-private.h"
@@ -34,8 +33,6 @@
 #include "gegl-buffer-cl-cache.h"
 #include "gegl-config.h"
 
-#define GEGL_ITERATOR_INCOMPATIBLE (1 << 2)
-
 typedef enum {
   GeglIteratorState_Start,
   GeglIteratorState_InTile,
@@ -554,8 +551,11 @@ _gegl_buffer_iterator_stop (GeglBufferIterator *iter)
 
           gegl_buffer_unlock (sub->buffer);
 
-          if (sub->access_mode & GEGL_ACCESS_WRITE)
-            gegl_buffer_emit_changed_signal (sub->buffer, &sub->full_rect);
+          if ((sub->access_mode & GEGL_ACCESS_WRITE) &&
+              ! (sub->access_mode & GEGL_ITERATOR_NO_NOTIFY))
+            {
+              gegl_buffer_emit_changed_signal (sub->buffer, &sub->full_rect);
+            }
         }
     }
 
