@@ -164,13 +164,16 @@ struct _GeglTile
   guint            stored_rev;  /* what revision was we when we from tile_storage?
                                    (currently set to 1 when loaded from disk */
 
-  gint             lock;        /* number of times the tile is write locked
-                                 * should in theory just have the values 0/1
-                                 */
+  gint             lock_count;  /* number of outstanding write locks */
   gint             is_zero_tile:1;
 
-  gint            *n_clones;    /* shared atomic counter among all tiles
-                                 * sharing the same data
+  gint             clone_state; /* tile clone/unclone state & spinlock */
+  gint            *n_clones;    /* an array of two atomic counters, shared
+                                 * among all tiles sharing the same data.
+                                 * the first counter indicates the number of
+                                 * tiles sharing the data, and the second
+                                 * counter indicates how many of those tiles
+                                 * are in the cache.
                                  */
 
   /* called when the tile is about to be destroyed */
@@ -186,8 +189,7 @@ struct _GeglTile
 
 void _gegl_buffer_drop_hot_tile (GeglBuffer *buffer);
 
-GeglRectangle _gegl_get_required_for_scale (const Babl          *format,
-                                            const GeglRectangle *roi,
+GeglRectangle _gegl_get_required_for_scale (const GeglRectangle *roi,
                                             gdouble              scale);
 
 gboolean gegl_buffer_scan_compatible (GeglBuffer *bufferA,
@@ -201,6 +203,9 @@ gboolean gegl_buffer_scan_compatible (GeglBuffer *bufferA,
 #define gegl_tile_get_data(tile)  ((tile)->data)
 #endif
 
+#define gegl_tile_n_clones(tile)         (&(tile)->n_clones[0])
+#define gegl_tile_n_cached_clones(tile)  (&(tile)->n_clones[1])
+
 /* computes the positive integer remainder (also for negative dividends)
  */
 #define GEGL_REMAINDER(dividend, divisor) \
