@@ -36,8 +36,6 @@
 #include <glib-object.h>
 #include <glib/gstdio.h>
 
-#include "gegl.h"
-#include "gegl-types-internal.h"
 #include "gegl-buffer-types.h"
 #include "gegl-buffer.h"
 #include "gegl-buffer-private.h"
@@ -46,9 +44,8 @@
 #include "gegl-tile-backend-file.h"
 #include "gegl-tile-backend-swap.h"
 #include "gegl-tile-backend-ram.h"
-#include "gegl-types-internal.h"
-#include "gegl-config.h"
 #include "gegl-buffer-cl-cache.h"
+#include "gegl-config.h" /* XXX: include of file outside buffer dir */
 
 #ifdef GEGL_ENABLE_DEBUG
 #define DEBUG_ALLOCATIONS (gegl_debug_flags & GEGL_DEBUG_BUFFER_ALLOC)
@@ -211,7 +208,8 @@ gegl_buffer_set_property (GObject      *gobject,
         break;
 
       case PROP_PATH:
-        g_free (buffer->path);
+        if (buffer->path)
+          g_free (buffer->path);
         buffer->path = g_value_dup_string (value);
         break;
 
@@ -263,7 +261,8 @@ gegl_buffer_set_property (GObject      *gobject,
         break;
 
       case PROP_BACKEND:
-        g_clear_object (&buffer->backend);
+        if (buffer->backend)
+          g_object_unref (buffer->backend);
         buffer->backend = g_value_dup_object (value);
         break;
 
@@ -274,10 +273,11 @@ gegl_buffer_set_property (GObject      *gobject,
 }
 
 #ifdef GEGL_ENABLE_DEBUG
-static GList *allocated_buffers_list = NULL;
+static GMutex         allocated_buffers_mutex;
+static GList         *allocated_buffers_list = NULL;
 #endif
-static gint   allocated_buffers      = 0;
-static gint   de_allocated_buffers   = 0;
+static volatile gint  allocated_buffers      = 0;
+static volatile gint  de_allocated_buffers   = 0;
 
 /* this should only be possible if this buffer matches all the buffers down to
  * storage, all of those parent buffers would change size as well, no tiles
@@ -326,6 +326,9 @@ gegl_buffer_leaks (void)
     {
       GList *leaked_buffer = NULL;
 
+      if (gegl_config_threads()>1)
+        g_mutex_lock (&allocated_buffers_mutex);
+
       for (leaked_buffer = allocated_buffers_list;
            leaked_buffer != NULL;
            leaked_buffer = leaked_buffer->next)
@@ -339,8 +342,12 @@ gegl_buffer_leaks (void)
           putc ('\n', stderr);
 #endif
         }
+
       g_list_free (allocated_buffers_list);
       allocated_buffers_list = NULL;
+
+      if (gegl_config_threads()>1)
+        g_mutex_unlock (&allocated_buffers_mutex);
     }
 #endif
 
@@ -386,7 +393,11 @@ gegl_buffer_dispose (GObject *object)
 
   _gegl_buffer_drop_hot_tile (buffer);
 
-  g_clear_object (&buffer->backend);
+  if (buffer->backend)
+    {
+      g_object_unref (buffer->backend);
+      buffer->backend = NULL;
+    }
 
   G_OBJECT_CLASS (parent_class)->dispose (object);
 }
@@ -397,13 +408,17 @@ gegl_buffer_finalize (GObject *object)
 #ifdef GEGL_ENABLE_DEBUG
   if (DEBUG_ALLOCATIONS)
     {
-      g_free (GEGL_BUFFER (object)->alloc_stack_trace);
+      if (gegl_config_threads()>1)
+        g_mutex_lock (&allocated_buffers_mutex);
       allocated_buffers_list = g_list_remove (allocated_buffers_list, object);
+      if (gegl_config_threads()>1)
+        g_mutex_unlock (&allocated_buffers_mutex);
+      g_free (GEGL_BUFFER (object)->alloc_stack_trace);
     }
 #endif
 
   g_free (GEGL_BUFFER (object)->path);
-  de_allocated_buffers++;
+  g_atomic_int_inc (&de_allocated_buffers);
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -502,7 +517,8 @@ gegl_buffer_constructor (GType                  type,
           buffer->tile_width = gegl_tile_backend_get_tile_width (backend);
           buffer->tile_height = gegl_tile_backend_get_tile_height (backend);
 
-          g_free (buffer->path);
+          if (buffer->path)
+            g_free (buffer->path);
 
           if (GEGL_IS_TILE_BACKEND_FILE (backend))
             g_object_get (backend, "path", &buffer->path, NULL);
@@ -910,13 +926,17 @@ gegl_buffer_init (GeglBuffer *buffer)
 
   ((GeglTileSource*)buffer)->command = gegl_buffer_command;
 
-  allocated_buffers++;
+  g_atomic_int_inc (&allocated_buffers);
 
 #ifdef GEGL_ENABLE_DEBUG
   if (DEBUG_ALLOCATIONS)
     {
       gegl_buffer_set_alloc_stack (buffer);
+      if (gegl_config_threads()>1)
+        g_mutex_lock (&allocated_buffers_mutex);
       allocated_buffers_list = g_list_prepend (allocated_buffers_list, buffer);
+      if (gegl_config_threads()>1)
+        g_mutex_unlock (&allocated_buffers_mutex);
     }
 #endif
 }
