@@ -49,7 +49,11 @@ gegl_tile_handler_dispose (GObject *object)
 {
   GeglTileHandler *handler = GEGL_TILE_HANDLER (object);
 
-  g_clear_object (&handler->source);
+  if (handler->source)
+    {
+      g_object_unref (handler->source);
+      handler->source = NULL;
+    }
 
   G_OBJECT_CLASS (gegl_tile_handler_parent_class)->dispose (object);
 }
@@ -141,7 +145,16 @@ void
 gegl_tile_handler_set_source (GeglTileHandler *handler,
                               GeglTileSource  *source)
 {
-  g_set_object (&handler->source, source);
+  if (source != handler->source)
+    {
+      if (handler->source)
+        g_object_unref (handler->source);
+
+      handler->source = source;
+
+      if (handler->source)
+        g_object_ref (handler->source);
+    }
 }
 
 void
