@@ -26,15 +26,9 @@
 
 #include <glib-object.h>
 
-#include "gegl-types-internal.h"
-
-#include "gegl.h"
-#include "gegl-buffer.h"
 #include "gegl-tile.h"
 #include "gegl-buffer-private.h"
-#include "gegl-tile-source.h"
 #include "gegl-tile-storage.h"
-#include "gegl-tile-handler-cache.h"
 #include "gegl-config.h"
 
 /* the offset at which the tile data begins, when it shares the same buffer as
@@ -146,6 +140,13 @@ gegl_tile_dup (GeglTile *src)
   tile->clone_state  = CLONE_STATE_CLONED;
   tile->n_clones     = src->n_clones;
 
+  /* if the tile is not empty, mark it as dirty, since, even though the in-
+   * memory tile data is shared with the source tile, the stored tile data is
+   * separate.
+   */
+  if (! tile->is_zero_tile)
+    tile->rev++;
+
   tile->destroy_notify      = src->destroy_notify;
   tile->destroy_notify_data = src->destroy_notify_data;
 
