@@ -25,6 +25,7 @@
 GeglTile   * gegl_tile_new            (gint             size);
 GeglTile   * gegl_tile_new_bare       (void);
 GeglTile   * gegl_tile_ref            (GeglTile         *tile);
+
 void         gegl_tile_unref          (GeglTile         *tile);
 
 /* lock a tile for writing, this would allow writing to buffers
@@ -55,7 +56,7 @@ void         gegl_tile_set_data       (GeglTile         *tile,
 void         gegl_tile_set_data_full  (GeglTile         *tile,
                                        gpointer          pixel_data,
                                        gint              pixel_data_size,
-                                       GeglDestroyNotify destroy_notify,
+                                       GDestroyNotify    destroy_notify,
                                        gpointer          destroy_notify_data);
 
 void         gegl_tile_set_unlock_notify
