@@ -24,60 +24,69 @@ G_BEGIN_DECLS
 #define GEGL_SCALE_EPSILON 1.e-6
 
 void gegl_downscale_2x2 (const Babl *format,
-                         gint    src_width,
-                         gint    src_height,
-                         guchar *src_data,
-                         gint    src_rowstride,
-                         guchar *dst_data,
-                         gint    dst_rowstride);
+                         gint        src_width,
+                         gint        src_height,
+                         guchar     *src_data,
+                         gint        src_rowstride,
+                         guchar     *dst_data,
+                         gint        dst_rowstride);
 
-void gegl_downscale_2x2_double (gint    bpp,
-                                gint    src_width,
-                                gint    src_height,
-                                guchar *src_data,
-                                gint    src_rowstride,
-                                guchar *dst_data,
-                                gint    dst_rowstride);
 
-void gegl_downscale_2x2_float (gint    bpp,
-                               gint    src_width,
-                               gint    src_height,
-                               guchar *src_data,
-                               gint    src_rowstride,
-                               guchar *dst_data,
-                               gint    dst_rowstride);
+void gegl_downscale_2x2_double (const Babl *format,
+                                gint        src_width,
+                                gint        src_height,
+                                guchar     *src_data,
+                                gint        src_rowstride,
+                                guchar     *dst_data,
+                                gint        dst_rowstride);
 
-void gegl_downscale_2x2_u32 (gint    bpp,
-                             gint    src_width,
-                             gint    src_height,
-                             guchar *src_data,
-                             gint    src_rowstride,
-                             guchar *dst_data,
-                             gint    dst_rowstride);
+void gegl_downscale_2x2_float (const Babl *format,
+                               gint        src_width,
+                               gint        src_height,
+                               guchar     *src_data,
+                               gint        src_rowstride,
+                               guchar     *dst_data,
+                               gint        dst_rowstride);
 
-void gegl_downscale_2x2_u16 (gint    bpp,
-                             gint    src_width,
-                             gint    src_height,
-                             guchar *src_data,
-                             gint    src_rowstride,
-                             guchar *dst_data,
-                             gint    dst_rowstride);
+typedef void (*GeglDownscale2x2Fun) (const Babl *format,
+                                     gint    src_width,
+                                     gint    src_height,
+                                     guchar *src_data,
+                                     gint    src_rowstride,
+                                     guchar *dst_data,
+                                     gint    dst_rowstride);
 
-void gegl_downscale_2x2_u8 (gint    bpp,
-                            gint    src_width,
-                            gint    src_height,
-                            guchar *src_data,
-                            gint    src_rowstride,
-                            guchar *dst_data,
-                            gint    dst_rowstride);
+void gegl_downscale_2x2_u32 (const Babl *format,
+                             gint        src_width,
+                             gint        src_height,
+                             guchar     *src_data,
+                             gint        src_rowstride,
+                             guchar     *dst_data,
+                             gint        dst_rowstride);
 
-void gegl_downscale_2x2_nearest (gint    bpp,
-                                 gint    src_width,
-                                 gint    src_height,
-                                 guchar *src_data,
-                                 gint    src_rowstride,
-                                 guchar *dst_data,
-                                 gint    dst_rowstride);
+void gegl_downscale_2x2_u16 (const Babl *format,
+                             gint        src_width,
+                             gint        src_height,
+                             guchar     *src_data,
+                             gint        src_rowstride,
+                             guchar     *dst_data,
+                             gint        dst_rowstride);
+
+void gegl_downscale_2x2_u8 (const Babl *format,
+                            gint        src_width,
+                            gint        src_height,
+                            guchar     *src_data,
+                            gint        src_rowstride,
+                            guchar     *dst_data,
+                            gint        dst_rowstride);
+
+void gegl_downscale_2x2_nearest (const Babl *format,
+                                 gint        src_width,
+                                 gint        src_height,
+                                 guchar     *src_data,
+                                 gint        src_rowstride,
+                                 guchar      *dst_data,
+                                 gint        dst_rowstride);
 
 /* Attempt to resample with a 3x3 boxfilter, if no boxfilter is
  * available for #format fall back to nearest neighbor.
@@ -203,6 +212,7 @@ void gegl_resample_nearest (guchar              *dst,
                             gint                 bpp,
                             gint                 dst_stride);
 
+GeglDownscale2x2Fun gegl_downscale_2x2_get_fun (const Babl *format);
 
 G_END_DECLS
 
