@@ -255,18 +255,14 @@ gegl_dot_add_node_and_dependencies (GString  *string,
 {
   GeglDotVisitor *dot_visitor;
   GeglPad        *pad;
-  gpointer        context_id = string;
 
-  dot_visitor = g_object_new (GEGL_TYPE_DOT_VISITOR,
-                              "id", context_id,
-                              NULL);
+  dot_visitor = g_object_new (GEGL_TYPE_DOT_VISITOR, NULL);
 
   gegl_dot_visitor_set_string_to_append (dot_visitor,
                                          string);
 
   /* Add the nodes */
-  gegl_visitor_bfs_traverse (GEGL_VISITOR (dot_visitor),
-                             GEGL_VISITABLE (node));
+  gegl_visitor_traverse (GEGL_VISITOR (dot_visitor), GEGL_VISITABLE (node));
 
   /* Add the edges */
   pad = gegl_node_get_pad (node, "output");
@@ -288,8 +284,7 @@ gegl_dot_add_node_and_dependencies (GString  *string,
     }
 
 
-  gegl_visitor_bfs_traverse (GEGL_VISITOR (dot_visitor),
-                             GEGL_VISITABLE (pad));
+  gegl_visitor_traverse (GEGL_VISITOR (dot_visitor), GEGL_VISITABLE (pad));
 
   g_object_unref (dot_visitor);
 }
