@@ -35,6 +35,9 @@ gegl_abyss_policy_get_type (void)
         { GEGL_ABYSS_LOOP,  N_("Loop"),  "loop"  },
         { GEGL_ABYSS_BLACK, N_("Black"), "black" },
         { GEGL_ABYSS_WHITE, N_("White"), "white" },
+        // we do not really want this one introspected/translated,
+        // will this bite us?
+        //{ GEGL_BUFFER_NEAREST, N_("Nearest"), "nearest" },
         { 0, NULL, NULL }
       };
       gint i;
@@ -109,6 +112,33 @@ gegl_dither_method_get_type (void)
   return etype;
 }
 
+GType
+gegl_distance_metric_get_type (void)
+{
+  static GType etype = 0;
+
+  if (etype == 0)
+    {
+      static GEnumValue values[] = {
+        { GEGL_DISTANCE_METRIC_EUCLIDEAN, N_("Euclidean"), "euclidean"  },
+        { GEGL_DISTANCE_METRIC_MANHATTAN, N_("Manhattan"), "manhattan"  },
+        { GEGL_DISTANCE_METRIC_CHEBYSHEV, N_("Chebyshev"), "chebyshev" },
+
+        { 0, NULL, NULL }
+      };
+      gint i;
+
+      for (i = 0; i < G_N_ELEMENTS (values); i++)
+        if (values[i].value_name)
+          values[i].value_name =
+            dgettext (GETTEXT_PACKAGE, values[i].value_name);
+
+      etype = g_enum_register_static ("GeglDistanceMetric", values);
+    }
+
+  return etype;
+}
+
 GType
 gegl_orientation_get_type (void)
 {
