@@ -102,6 +102,7 @@ guint gegl_debug_flags = 0;
 #include "buffer/gegl-tile-backend-ram.h"
 #include "buffer/gegl-tile-backend-file.h"
 #include "gegl-config.h"
+#include "gegl-stats.h"
 #include "graph/gegl-node-private.h"
 #include "gegl-random-private.h"
 
@@ -113,6 +114,8 @@ static gboolean  gegl_post_parse_hook (GOptionContext *context,
 
 static GeglConfig   *config = NULL;
 
+static GeglStats    *stats = NULL;
+
 static GeglModuleDB *module_db   = NULL;
 
 static glong         global_time = 0;
@@ -235,6 +238,8 @@ gboolean gegl_is_main_thread (void)
   return g_thread_self () == main_thread;
 }
 
+void _gegl_init_u8_lut (void);
+
 void
 gegl_init (gint    *argc,
            gchar ***argv)
@@ -247,6 +252,7 @@ gegl_init (gint    *argc,
     return;
 
 
+
   initialized = TRUE;
 
   context = g_option_context_new (NULL);
@@ -415,6 +421,19 @@ GeglConfig *gegl_config (void)
   return config;
 }
 
+GeglStats *gegl_stats (void)
+{
+  if (! stats)
+    stats = g_object_new (GEGL_TYPE_STATS, NULL);
+
+  return stats;
+}
+
+void gegl_reset_stats (void)
+{
+  gegl_stats_reset (gegl_stats ());
+}
+
 static void swap_clean (void)
 {
   const gchar  *swap_dir = gegl_swap_dir ();
@@ -634,6 +653,7 @@ gegl_post_parse_hook (GOptionContext *context,
   gegl_config_parse_env (config);
 
   babl_init ();
+  _gegl_init_u8_lut ();
 
 #ifdef GEGL_ENABLE_DEBUG
   {
