@@ -21,6 +21,9 @@
 
 gchar    * gegl_node_to_xml        (GeglNode    *gegl,
                                     const gchar *path_root);
+gchar    * gegl_node_to_xml_full   (GeglNode    *head,
+                                    GeglNode    *tail,
+                                    const gchar *path_root);
 GeglNode * gegl_node_new_from_xml  (const gchar *xmldata,
                                     const gchar *path_root);
 GeglNode * gegl_node_new_from_file (const gchar *path);
