@@ -31,6 +31,7 @@
 #include <sys/types.h>
 #include <unistd.h>
 #include <string.h>
+#include "gegl-buffer-cl-cache.h"
 
 typedef struct ThreadData
 {
@@ -127,14 +128,14 @@ gegl_operation_composer3_process (GeglOperation        *operation,
     return TRUE;
   }
 
-  input  = gegl_operation_context_get_source (context, "input");
+  input  = (GeglBuffer*) gegl_operation_context_dup_object (context, "input");
   output = gegl_operation_context_get_output_maybe_in_place (operation,
                                                              context,
                                                              input,
                                                              result);
 
-  aux   = gegl_operation_context_get_source (context, "aux");
-  aux2  = gegl_operation_context_get_source (context, "aux2");
+  aux   = (GeglBuffer*) gegl_operation_context_dup_object (context, "aux");
+  aux2  = (GeglBuffer*) gegl_operation_context_dup_object (context, "aux2");
 
   /* A composer with a NULL aux, can still be valid, the
    * subclass has to handle it.
@@ -232,15 +233,37 @@ gegl_operation_point_composer3_process (GeglOperation       *operation,
         GThreadPool *pool = thread_pool ();
         gint pending;
         gint j;
-        GeglRectangle sub_result;
+
+        if (result->width > result->height)
+          for (j = 0; j < threads; j++)
+          {
+            GeglRectangle rect = *result;
+
+            rect.width /= threads;
+            rect.x += rect.width * j;
+
+            if (j == threads-1)
+              rect.width = (result->width + result->x) - rect.x;
+
+            thread_data[j].result = rect;
+          }
+        else
+          for (j = 0; j < threads; j++)
+          {
+            GeglRectangle rect = *result;
+
+            rect = *result;
+            rect.height /= threads;
+            rect.y += rect.height * j;
+
+            if (j == threads-1)
+              rect.height = (result->height + result->y) - rect.y;
+
+            thread_data[j].result = rect;
+          }
 
         for (j = 0; j < threads; j++)
         {
-           sub_result = *result;
-           sub_result.height /= threads;
-           sub_result.y += sub_result.height * j;
-           if (j == threads-1)
-             sub_result.height = (result->height + result->y) - sub_result.y;
           thread_data[j].klass = point_composer3_class;
           thread_data[j].operation = operation;
           thread_data[j].input = input;
@@ -253,9 +276,19 @@ gegl_operation_point_composer3_process (GeglOperation       *operation,
           thread_data[j].aux_format = aux_format;
           thread_data[j].aux2_format = aux2_format;
           thread_data[j].output_format = out_format;
-          thread_data[j].result = sub_result;
         }
         pending = threads;
+
+        if (gegl_cl_is_accelerated ())
+        {
+          if (input)
+            gegl_buffer_cl_cache_flush (input, result);
+          if (aux)
+            gegl_buffer_cl_cache_flush (aux, result);
+          if (aux2)
+            gegl_buffer_cl_cache_flush (aux2, result);
+        }
+
         for (gint j = 1; j < threads; j++)
           g_thread_pool_push (pool, &thread_data[j], NULL);
         thread_process (&thread_data[0], NULL);
