@@ -424,114 +424,6 @@ gegl_param_spec_file_path (const gchar *name,
   return G_PARAM_SPEC (sspec);
 }
 
-
-/*
- * GEGL_TYPE_PARAM_MULTILINE
- */
-
-static void       gegl_param_multiline_class_init (GParamSpecClass *klass);
-static void       gegl_param_multiline_init (GParamSpec *pspec);
-static gboolean   gegl_param_multiline_validate (GParamSpec *pspec,
-                                                 GValue     *value);
-
-GType
-gegl_param_multiline_get_type (void)
-{
-  static GType type = 0;
-
-  if (!type)
-    {
-      const GTypeInfo info =
-      {
-        sizeof (GParamSpecClass),
-        NULL,                                             NULL,
-        (GClassInitFunc) gegl_param_multiline_class_init,
-        NULL,                                             NULL,
-        sizeof (GeglParamSpecString),
-        0,
-        (GInstanceInitFunc) gegl_param_multiline_init
-      };
-
-      type = g_type_register_static (G_TYPE_PARAM_STRING,
-                                     "GeglParamMultiline", &info, 0);
-    }
-
-  return type;
-}
-
-static void
-gegl_param_multiline_class_init (GParamSpecClass *klass)
-{
-  klass->value_type     = G_TYPE_STRING;
-  klass->value_validate = gegl_param_multiline_validate;
-}
-
-static void
-gegl_param_multiline_init (GParamSpec *pspec)
-{
-  GeglParamSpecMultiline *sspec = GEGL_PARAM_SPEC_MULTILINE (pspec);
-
-  sspec->no_validate = FALSE;
-  sspec->null_ok     = FALSE;
-}
-
-static gboolean
-gegl_param_multiline_validate (GParamSpec *pspec,
-                               GValue     *value)
-{
-  GeglParamSpecMultiline *sspec     = GEGL_PARAM_SPEC_MULTILINE (pspec);
-  gchar                  *multiline = value->data[0].v_pointer;
-
-  if (multiline)
-    {
-      gchar *s;
-
-      if (!sspec->no_validate &&
-          !g_utf8_validate (multiline, -1, (const gchar **) &s))
-        {
-          for (; *s; s++)
-            if (*s < ' ')
-              *s = '?';
-
-          return TRUE;
-        }
-    }
-  else if (!sspec->null_ok)
-    {
-      value->data[0].v_pointer = g_strdup ("");
-      return TRUE;
-    }
-
-  return FALSE;
-}
-
-GParamSpec *
-gegl_param_spec_multiline (const gchar *name,
-                           const gchar *nick,
-                           const gchar *blurb,
-                           const gchar *default_value,
-                           GParamFlags  flags)
-{
-  GeglParamSpecMultiline *sspec;
-
-  sspec = g_param_spec_internal (GEGL_TYPE_PARAM_MULTILINE,
-                                 name, nick, blurb, flags);
-
-  if (sspec)
-    {
-      g_free (G_PARAM_SPEC_STRING (sspec)->default_value);
-      G_PARAM_SPEC_STRING (sspec)->default_value = g_strdup (default_value);
-/*
-      sspec->no_validate = no_validate ? TRUE : FALSE;
-      sspec->null_ok     = null_ok     ? TRUE : FALSE;*/
-    }
-
-  return G_PARAM_SPEC (sspec);
-}
-
-
-
-
 /*
  * GEGL_TYPE_PARAM_ENUM
  */
