@@ -1,8 +1,4 @@
 static const char* motion_blur_linear_cl_source =
-"int CLAMP(int val,int lo,int hi)                                              \n"
-"{                                                                             \n"
-"    return (val < lo) ? lo : ((hi < val) ? hi : val);                         \n"
-"}                                                                             \n"
 "                                                                              \n"
 "float4 get_pixel_color(const __global float4 *in_buf,                         \n"
 "                       int     rect_width,                                    \n"
@@ -15,8 +11,8 @@ static const char* motion_blur_linear_cl_source =
 "    int ix = x - rect_x;                                                      \n"
 "    int iy = y - rect_y;                                                      \n"
 "                                                                              \n"
-"    ix = CLAMP(ix, 0, rect_width-1);                                          \n"
-"    iy = CLAMP(iy, 0, rect_height-1);                                         \n"
+"    ix = clamp(ix, 0, rect_width-1);                                          \n"
+"    iy = clamp(iy, 0, rect_height-1);                                         \n"
 "                                                                              \n"
 "    return in_buf[iy * rect_width + ix];                                      \n"
 "}                                                                             \n"
