@@ -24,8 +24,9 @@
 
 #ifdef GEGL_PROPERTIES
 
-property_int  (holdness, _("Holdness"), 2)
+property_int  (holdness, _("Dulling"), 2)
   value_range (1, 8)
+  description (_("A high value lowers the randomness of the noise"))
 
 property_double (hue_distance, _("Hue"), 3.0)
   value_range   (0.0, 180.0)
@@ -274,7 +275,7 @@ gegl_op_class_init (GeglOpClass *klass)
     "name",       "gegl:noise-hsv",
     "title",      _("Add HSV Noise"),
     "categories", "noise",
-    "reference-hash", "5754cd0bcadabd01bbc253b5c41cbd74",
+    "reference-hash", "e750e20f35e03f6c64a38bcc9c11490d",
     "description", _("Randomize hue, saturation and value independently"),
       NULL);
 }
