@@ -105,7 +105,7 @@ read_from_stream (GInputStream *stream,
   return read;
 }
 
-static gsize
+static glong
 decode_from_stream (GInputStream *stream,
                     WebPIDecoder *decoder)
 {
@@ -317,9 +317,7 @@ finalize(GObject *object)
   if (o->user_data != NULL)
     {
       cleanup (GEGL_OPERATION (object));
-      if (o->user_data != NULL)
-        g_free (o->user_data);
-      o->user_data = NULL;
+      g_clear_pointer (&o->user_data, g_free);
     }
 
   G_OBJECT_CLASS (gegl_op_parent_class)->finalize (object);
