@@ -19,8 +19,8 @@ struct _OpTransform
   GeglOperationFilter parent_instance;
   gdouble             origin_x;
   gdouble             origin_y;
+  gdouble             near_z;
   GeglSamplerType     sampler;
-  gboolean            clip_to_input;
 };
 
 typedef struct _OpTransformClass OpTransformClass;
@@ -29,8 +29,9 @@ struct _OpTransformClass
 {
   GeglOperationFilterClass parent_class;
 
-  void (* create_matrix) (OpTransform  *transform,
-                          GeglMatrix3  *matrix);
+  void            (* create_matrix)    (OpTransform *transform,
+                                        GeglMatrix3 *matrix);
+  GeglAbyssPolicy (* get_abyss_policy) (OpTransform *transform);
 };
 
 GType op_transform_get_type (void) G_GNUC_CONST;
