@@ -33,6 +33,15 @@ TestCase tests[] = {
      "gegl:invert-linear",
      ""},
 
+    {"threshold value=0.1",
+     "gegl:threshold value=0.10000000000000001",
+     ""},
+
+
+    {"threshold value={ 0=0.1 2=0.33 }",
+     "gegl:threshold value={  0=0.10000000149011612  2=0.33000001311302185  } ",
+     ""},
+
     {"invert a=b",
      "gegl:invert-linear",
      "gegl:invert has no a property."},
@@ -55,6 +64,12 @@ TestCase tests[] = {
     {"over aux=[text string='foo bar' ]",
      "svg:src-over aux=[  gegl:text string='foo bar' width=33 height=7 ]\n",
      ""},
+    {"over aux=[text string='foo bar']",
+     "svg:src-over aux=[  gegl:text string='foo bar' width=33 height=7 ]\n",
+     ""},
+    {"over aux=[ text string={ 0='foo bar' } ]",
+     "svg:src-over aux=[  gegl:text string='foo bar' width=33 height=7 ]\n",
+     ""},
      */
 
     {"over aux= [ ",
@@ -79,12 +94,8 @@ TestCase tests[] = {
      "gegl:exposure",
      "gegl:exposure has no foo property, properties: 'black-level', 'exposure', "},
 
-    {"over aux=[text string='foo bar']",
-     "svg:src-over aux=[  gegl:text string='foo bar' width=33 height=7 ]\n",
-     ""},
-
     {"over aux=[ load path=/ ]",
-     "svg:src-over aux=[  gegl:load path='/' ]\n",
+     "svg:src-over aux=[  gegl:load path='/' ] ",
      ""},
 
     {"inver",
@@ -92,20 +103,17 @@ TestCase tests[] = {
      "No such op 'gegl:inver' suggestions: gegl:invert-gamma gegl:invert-linear"},
 
     {"over aux=[ load path=/abc ]",
-     "svg:src-over aux=[  gegl:load path='/abc' ]\n",
+     "svg:src-over aux=[  gegl:load path='/abc' ] ",
      ""},
 
     {"id=foo over aux=[ ref=foo invert ]",
-     "id=foo\n svg:src-over aux=[  ref=foo\n gegl:invert-linear ]\n",
+     "id=foo\n svg:src-over aux=[  ref=foo\n gegl:invert-linear ] ",
      ""},
 
     {"id=bar id=foo over aux=[ ref=foo invert ]",
-     "id=foo\n svg:src-over aux=[  ref=foo\n gegl:invert-linear ]\n",
+     "id=foo\n svg:src-over aux=[  ref=foo\n gegl:invert-linear ] ",
      ""},
 
-    {"over aux=[ text string={ 0='foo bar' } ]",
-     "svg:src-over aux=[  gegl:text string='foo bar' width=33 height=7 ]\n",
-     ""},
 
     {NULL, NULL, NULL}
 };
